@@ -12,7 +12,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "ffmpegthumbnailer.h"
 #include "ffmpegthumbnailersettings5.h"
@@ -42,7 +42,7 @@ FFMpegThumbnailer::~FFMpegThumbnailer()
 {
 }
 
-bool FFMpegThumbnailer::create(const QString& path, int width, int /*heigth*/, QImage& img)
+bool FFMpegThumbnailer::create(const QString& path, int width, int /*height*/, QImage& img)
 {
     m_Thumbnailer.setThumbnailSize(width);
     // 20% seek inside the video to generate the preview
